@@ -39,32 +39,29 @@ namespace ranges
     namespace detail
     {
         template(typename I, typename S)(
-            /// \pre
             requires input_iterator<I> AND sentinel_for<S, I>)
-        I next_to_if(I i, S s, std::true_type)
+        constexpr I next_to_if(I i, S s, std::true_type)
         {
             return ranges::next(i, s);
         }
 
         template(typename I, typename S)(
-            /// \pre
             requires input_iterator<I> AND sentinel_for<S, I>)
-        S next_to_if(I, S s, std::false_type)
+        constexpr S next_to_if(I, S s, std::false_type)
         {
             return s;
         }
 
         template(bool B, typename I, typename S)(
-            /// \pre
             requires input_iterator<I> AND sentinel_for<S, I>)
-        meta::if_c<B, I, S> next_to_if(I i, S s)
+        constexpr meta::if_c<B, I, S> next_to_if(I i, S s)
         {
             return detail::next_to_if(std::move(i), std::move(s), meta::bool_<B>{});
         }
 
         template<typename I1, typename S1, typename I2, typename S2, typename R,
                  typename P>
-        subrange<I1> find_end_impl(I1 begin1, S1 end1, I2 begin2, S2 end2, R pred, P proj,
+        constexpr subrange<I1> find_end_impl(I1 begin1, S1 end1, I2 begin2, S2 end2, R pred, P proj,
                                    std::forward_iterator_tag, std::forward_iterator_tag)
         {
             bool found = false;
@@ -107,7 +104,7 @@ namespace ranges
         }
 
         template<typename I1, typename I2, typename R, typename P>
-        subrange<I1> find_end_impl(I1 begin1, I1 end1, I2 begin2, I2 end2, R pred, P proj,
+        constexpr subrange<I1> find_end_impl(I1 begin1, I1 end1, I2 begin2, I2 end2, R pred, P proj,
                                    std::bidirectional_iterator_tag,
                                    std::bidirectional_iterator_tag)
         {
@@ -144,7 +141,7 @@ namespace ranges
         }
 
         template<typename I1, typename I2, typename R, typename P>
-        subrange<I1> find_end_impl(I1 begin1, I1 end1, I2 begin2, I2 end2, R pred, P proj,
+        constexpr subrange<I1> find_end_impl(I1 begin1, I1 end1, I2 begin2, I2 end2, R pred, P proj,
                                    std::random_access_iterator_tag,
                                    std::random_access_iterator_tag)
         {
@@ -190,11 +187,10 @@ namespace ranges
                  typename S2,
                  typename R = equal_to,
                  typename P = identity)(
-            /// \pre
             requires forward_iterator<I1> AND sentinel_for<S1, I1> AND
                 forward_iterator<I2> AND sentinel_for<S2, I2> AND
                 indirect_relation<R, projected<I1, P>, I2>)
-        subrange<I1> RANGES_FUNC(find_end)(
+        constexpr subrange<I1> RANGES_FUNC(find_end)(
             I1 begin1, S1 end1, I2 begin2, S2 end2, R pred = R{}, P proj = P{}) //
         {
             constexpr bool Bidi =
@@ -214,10 +210,9 @@ namespace ranges
                  typename Rng2,
                  typename R = equal_to,
                  typename P = identity)(
-            /// \pre
             requires forward_range<Rng1> AND forward_range<Rng2> AND
                 indirect_relation<R, projected<iterator_t<Rng1>, P>, iterator_t<Rng2>>)
-        borrowed_subrange_t<Rng1> RANGES_FUNC(find_end)(
+        constexpr borrowed_subrange_t<Rng1> RANGES_FUNC(find_end)(
             Rng1 && rng1, Rng2 && rng2, R pred = R{}, P proj = P{}) //
         {
             return (*this)(begin(rng1),
