@@ -39,7 +39,7 @@
 #include <range/v3/range/traits.hpp>
 #include <range/v3/utility/static_const.hpp>
 
-#include <range/v3/detail/disable_warnings.hpp>
+#include <range/v3/detail/prologue.hpp>
 
 namespace ranges
 {
@@ -48,11 +48,13 @@ namespace ranges
     {
         struct is_heap_until_n_fn
         {
-            template<typename I, typename C = less, typename P = identity>
-            auto operator()(I const begin_, iter_difference_t<I> const n_, C pred = C{},
-                            P proj = P{}) const -> CPP_ret(I)( //
-                requires random_access_iterator<I> &&
+            template(typename I, typename C = less, typename P = identity)(
+                requires random_access_iterator<I> AND
                     indirect_strict_weak_order<C, projected<I, P>>)
+            constexpr I operator()(I const begin_, 
+                                   iter_difference_t<I> const n_, 
+                                   C pred = C{},
+                                   P proj = P{}) const
             {
                 RANGES_EXPECT(0 <= n_);
                 iter_difference_t<I> p = 0, c = 1;
@@ -78,11 +80,13 @@ namespace ranges
 
         struct is_heap_n_fn
         {
-            template<typename I, typename C = less, typename P = identity>
-            auto operator()(I first, iter_difference_t<I> n, C pred = C{},
-                            P proj = P{}) const -> CPP_ret(bool)( //
-                requires random_access_iterator<I> &&
+            template(typename I, typename C = less, typename P = identity)(
+                requires random_access_iterator<I> AND
                     indirect_strict_weak_order<C, projected<I, P>>)
+            constexpr bool operator()(I first, 
+                                      iter_difference_t<I> n, 
+                                      C pred = C{},
+                                      P proj = P{}) const
             {
                 return is_heap_until_n(first, n, std::move(pred), std::move(proj)) ==
                        first + n;
@@ -98,11 +102,10 @@ namespace ranges
     RANGES_FUNC_BEGIN(is_heap_until)
 
         /// \brief function template \c is_heap_until
-        template<typename I, typename S, typename C = less, typename P = identity>
-        auto RANGES_FUNC(is_heap_until)(I first, S last, C pred = C{}, P proj = P{})
-            ->CPP_ret(I)( //
-                requires random_access_iterator<I> && sentinel_for<S, I> &&
-                indirect_strict_weak_order<C, projected<I, P>>)
+        template(typename I, typename S, typename C = less, typename P = identity)(
+            requires random_access_iterator<I> AND sentinel_for<S, I> AND
+            indirect_strict_weak_order<C, projected<I, P>>)
+        constexpr I RANGES_FUNC(is_heap_until)(I first, S last, C pred = C{}, P proj = P{})
         {
             return detail::is_heap_until_n(std::move(first),
                                            distance(first, last),
@@ -111,11 +114,11 @@ namespace ranges
         }
 
         /// \overload
-        template<typename Rng, typename C = less, typename P = identity>
-        auto RANGES_FUNC(is_heap_until)(Rng && rng, C pred = C{}, P proj = P{})
-            ->CPP_ret(safe_iterator_t<Rng>)( //
-                requires random_access_range<Rng> &&
-                indirect_strict_weak_order<C, projected<iterator_t<Rng>, P>>)
+        template(typename Rng, typename C = less, typename P = identity)(
+            requires random_access_range<Rng> AND
+            indirect_strict_weak_order<C, projected<iterator_t<Rng>, P>>)
+        constexpr borrowed_iterator_t<Rng> //
+        RANGES_FUNC(is_heap_until)(Rng && rng, C pred = C{}, P proj = P{})
         {
             return detail::is_heap_until_n(
                 begin(rng), distance(rng), std::move(pred), std::move(proj));
@@ -131,11 +134,10 @@ namespace ranges
     RANGES_FUNC_BEGIN(is_heap)
 
         /// \brief function template \c is_heap
-        template<typename I, typename S, typename C = less, typename P = identity>
-        auto RANGES_FUNC(is_heap)(I first, S last, C pred = C{}, P proj = P{}) //
-            ->CPP_ret(bool)(                                                   //
-                requires random_access_iterator<I> && sentinel_for<S, I> &&
-                indirect_strict_weak_order<C, projected<I, P>>)
+        template(typename I, typename S, typename C = less, typename P = identity)(
+            requires random_access_iterator<I> AND sentinel_for<S, I> AND
+            indirect_strict_weak_order<C, projected<I, P>>)
+        constexpr bool RANGES_FUNC(is_heap)(I first, S last, C pred = C{}, P proj = P{}) //
         {
             return detail::is_heap_n(std::move(first),
                                      distance(first, last),
@@ -144,11 +146,10 @@ namespace ranges
         }
 
         /// \overload
-        template<typename Rng, typename C = less, typename P = identity>
-        auto RANGES_FUNC(is_heap)(Rng && rng, C pred = C{}, P proj = P{}) //
-            ->CPP_ret(bool)(                                              //
-                requires random_access_range<Rng> &&
-                indirect_strict_weak_order<C, projected<iterator_t<Rng>, P>>)
+        template(typename Rng, typename C = less, typename P = identity)(
+            requires random_access_range<Rng> AND
+            indirect_strict_weak_order<C, projected<iterator_t<Rng>, P>>)
+        constexpr bool RANGES_FUNC(is_heap)(Rng && rng, C pred = C{}, P proj = P{}) //
         {
             return detail::is_heap_n(
                 begin(rng), distance(rng), std::move(pred), std::move(proj));
@@ -168,8 +169,10 @@ namespace ranges
         struct sift_up_n_fn
         {
             template<typename I, typename C = less, typename P = identity>
-            void operator()(I first, iter_difference_t<I> len, C pred = C{},
-                            P proj = P{}) const
+            constexpr void operator()(I first, 
+                                      iter_difference_t<I> len, 
+                                      C pred = C{},
+                                      P proj = P{}) const
             {
                 if(len > 1)
                 {
@@ -199,8 +202,11 @@ namespace ranges
         struct sift_down_n_fn
         {
             template<typename I, typename C = less, typename P = identity>
-            void operator()(I first, iter_difference_t<I> len, I start, C pred = C{},
-                            P proj = P{}) const
+            constexpr void operator()(I first, 
+                                      iter_difference_t<I> len, 
+                                      I start, 
+                                      C pred = C{},
+                                      P proj = P{}) const
             {
                 // left-child of start is at 2 * start + 1
                 // right-child of start is at 2 * start + 2
@@ -262,11 +268,10 @@ namespace ranges
     RANGES_FUNC_BEGIN(push_heap)
 
         /// \brief function template \c push_heap
-        template<typename I, typename S, typename C = less, typename P = identity>
-        auto RANGES_FUNC(push_heap)(I first, S last, C pred = C{}, P proj = P{}) //
-            ->CPP_ret(I)(                                                        //
-                requires random_access_iterator<I> && sentinel_for<S, I> &&
-                sortable<I, C, P>)
+        template(typename I, typename S, typename C = less, typename P = identity)(
+            requires random_access_iterator<I> AND sentinel_for<S, I> AND
+            sortable<I, C, P>)
+        constexpr I RANGES_FUNC(push_heap)(I first, S last, C pred = C{}, P proj = P{})
         {
             auto n = distance(first, last);
             detail::sift_up_n(first, n, std::move(pred), std::move(proj));
@@ -274,10 +279,10 @@ namespace ranges
         }
 
         /// \overload
-        template<typename Rng, typename C = less, typename P = identity>
-        auto RANGES_FUNC(push_heap)(Rng && rng, C pred = C{}, P proj = P{}) //
-            ->CPP_ret(safe_iterator_t<Rng>)(                                //
-                requires random_access_range<Rng> && sortable<iterator_t<Rng>, C, P>)
+        template(typename Rng, typename C = less, typename P = identity)(
+            requires random_access_range<Rng> AND sortable<iterator_t<Rng>, C, P>)
+        constexpr borrowed_iterator_t<Rng> //
+        RANGES_FUNC(push_heap)(Rng && rng, C pred = C{}, P proj = P{}) //
         {
             iterator_t<Rng> first = ranges::begin(rng);
             auto n = distance(rng);
@@ -298,10 +303,12 @@ namespace ranges
     {
         struct pop_heap_n_fn
         {
-            template<typename I, typename C = less, typename P = identity>
-            auto operator()(I first, iter_difference_t<I> len, C pred = C{},
-                            P proj = P{}) const -> CPP_ret(void)( //
-                requires random_access_iterator<I> && sortable<I, C, P>)
+            template(typename I, typename C = less, typename P = identity)(
+                requires random_access_iterator<I> AND sortable<I, C, P>)
+            constexpr void operator()(I first, 
+                                      iter_difference_t<I> len, 
+                                      C pred = C{},
+                                      P proj = P{}) const
             {
                 if(len > 1)
                 {
@@ -321,11 +328,10 @@ namespace ranges
     RANGES_FUNC_BEGIN(pop_heap)
 
         /// \brief function template \c pop_heap
-        template<typename I, typename S, typename C = less, typename P = identity>
-        auto RANGES_FUNC(pop_heap)(I first, S last, C pred = C{}, P proj = P{})
-            ->CPP_ret(I)( //
-                requires random_access_iterator<I> && sentinel_for<S, I> &&
-                sortable<I, C, P>)
+        template(typename I, typename S, typename C = less, typename P = identity)(
+            requires random_access_iterator<I> AND sentinel_for<S, I> AND
+            sortable<I, C, P>)
+        constexpr I RANGES_FUNC(pop_heap)(I first, S last, C pred = C{}, P proj = P{})
         {
             auto n = distance(first, last);
             detail::pop_heap_n(first, n, std::move(pred), std::move(proj));
@@ -333,10 +339,10 @@ namespace ranges
         }
 
         /// \overload
-        template<typename Rng, typename C = less, typename P = identity>
-        auto RANGES_FUNC(pop_heap)(Rng && rng, C pred = C{}, P proj = P{})
-            ->CPP_ret(safe_iterator_t<Rng>)( //
-                requires random_access_range<Rng> && sortable<iterator_t<Rng>, C, P>)
+        template(typename Rng, typename C = less, typename P = identity)(
+            requires random_access_range<Rng> AND sortable<iterator_t<Rng>, C, P>)
+        constexpr borrowed_iterator_t<Rng> //
+        RANGES_FUNC(pop_heap)(Rng && rng, C pred = C{}, P proj = P{})
         {
             iterator_t<Rng> first = ranges::begin(rng);
             auto n = distance(rng);
@@ -354,26 +360,25 @@ namespace ranges
     RANGES_FUNC_BEGIN(make_heap)
 
         /// \brief function template \c make_heap
-        template<typename I, typename S, typename C = less, typename P = identity>
-        auto RANGES_FUNC(make_heap)(I first, S last, C pred = C{}, P proj = P{})
-            ->CPP_ret(I)( //
-                requires random_access_iterator<I> && sentinel_for<S, I> &&
-                sortable<I, C, P>)
+        template(typename I, typename S, typename C = less, typename P = identity)(
+            requires random_access_iterator<I> AND sentinel_for<S, I> AND
+            sortable<I, C, P>)
+        constexpr I RANGES_FUNC(make_heap)(I first, S last, C pred = C{}, P proj = P{})
         {
             iter_difference_t<I> const n = distance(first, last);
             if(n > 1)
                 // start from the first parent, there is no need to consider children
                 for(auto start = (n - 2) / 2; start >= 0; --start)
                     detail::sift_down_n(
-                        first, n, first + start, std::ref(pred), std::ref(proj));
+                        first, n, first + start, ranges::ref(pred), ranges::ref(proj));
             return first + n;
         }
 
         /// \overload
-        template<typename Rng, typename C = less, typename P = identity>
-        auto RANGES_FUNC(make_heap)(Rng && rng, C pred = C{}, P proj = P{})
-            ->CPP_ret(safe_iterator_t<Rng>)( //
-                requires random_access_range<Rng> && sortable<iterator_t<Rng>, C, P>)
+        template(typename Rng, typename C = less, typename P = identity)(
+            requires random_access_range<Rng> AND sortable<iterator_t<Rng>, C, P>)
+        constexpr borrowed_iterator_t<Rng> //
+        RANGES_FUNC(make_heap)(Rng && rng, C pred = C{}, P proj = P{})
         {
             iterator_t<Rng> first = ranges::begin(rng);
             auto const n = distance(rng);
@@ -381,7 +386,7 @@ namespace ranges
                 // start from the first parent, there is no need to consider children
                 for(auto start = (n - 2) / 2; start >= 0; --start)
                     detail::sift_down_n(
-                        first, n, first + start, std::ref(pred), std::ref(proj));
+                        first, n, first + start, ranges::ref(pred), ranges::ref(proj));
             return first + n;
         }
 
@@ -394,27 +399,26 @@ namespace ranges
 
     RANGES_FUNC_BEGIN(sort_heap)
 
-        template<typename I, typename S, typename C = less, typename P = identity>
-        auto RANGES_FUNC(sort_heap)(I first, S last, C pred = C{}, P proj = P{})
-            ->CPP_ret(I)( //
-                requires random_access_iterator<I> && sentinel_for<S, I> &&
-                sortable<I, C, P>)
+        template(typename I, typename S, typename C = less, typename P = identity)(
+            requires random_access_iterator<I> AND sentinel_for<S, I> AND
+            sortable<I, C, P>)
+        constexpr I RANGES_FUNC(sort_heap)(I first, S last, C pred = C{}, P proj = P{})
         {
             iter_difference_t<I> const n = distance(first, last);
             for(auto i = n; i > 1; --i)
-                detail::pop_heap_n(first, i, std::ref(pred), std::ref(proj));
+                detail::pop_heap_n(first, i, ranges::ref(pred), ranges::ref(proj));
             return first + n;
         }
 
-        template<typename Rng, typename C = less, typename P = identity>
-        auto RANGES_FUNC(sort_heap)(Rng && rng, C pred = C{}, P proj = P{})
-            ->CPP_ret(safe_iterator_t<Rng>)( //
-                requires random_access_range<Rng &> && sortable<iterator_t<Rng>, C, P>)
+        template(typename Rng, typename C = less, typename P = identity)(
+            requires random_access_range<Rng &> AND sortable<iterator_t<Rng>, C, P>)
+        constexpr borrowed_iterator_t<Rng> //
+        RANGES_FUNC(sort_heap)(Rng && rng, C pred = C{}, P proj = P{})
         {
             iterator_t<Rng> first = ranges::begin(rng);
             auto const n = distance(rng);
             for(auto i = n; i > 1; --i)
-                detail::pop_heap_n(first, i, std::ref(pred), std::ref(proj));
+                detail::pop_heap_n(first, i, ranges::ref(pred), ranges::ref(proj));
             return first + n;
         }
 
@@ -427,6 +431,6 @@ namespace ranges
     /// @}
 } // namespace ranges
 
-#include <range/v3/detail/reenable_warnings.hpp>
+#include <range/v3/detail/epilogue.hpp>
 
 #endif
