@@ -76,40 +76,40 @@ public:
 };
 
 template<typename I, typename V2>
-I upper_bound_n(I begin, typename std::iterator_traits<I>::difference_type d, V2 const &val)
+I upper_bound_n(I first, typename std::iterator_traits<I>::difference_type d, V2 const &val)
 {
     while(0 != d)
     {
         auto half = d / 2;
-        auto middle = std::next(begin, half);
+        auto middle = std::next(first, half);
         if(val < *middle)
             d = half;
         else
         {
-            begin = ++middle;
+            first = ++middle;
             d -= half + 1;
         }
     }
-    return begin;
+    return first;
 }
 
 template<typename I>
-void insertion_sort_n(I begin, typename std::iterator_traits<I>::difference_type n)
+void insertion_sort_n(I first, typename std::iterator_traits<I>::difference_type n)
 {
     auto m = 0;
-    for(auto it = begin; m != n; ++it, ++m)
+    for(auto it = first; m != n; ++it, ++m)
     {
-        auto insertion = upper_bound_n(begin, m, *it);
+        auto insertion = upper_bound_n(first, m, *it);
         ranges::rotate(insertion, it, std::next(it));
     }
 }
 
 template<typename I, typename S>
-void insertion_sort(I begin, S end)
+void insertion_sort(I first, S last)
 {
-    for(auto it = begin; it != end; ++it)
+    for(auto it = first; it != last; ++it)
     {
-        auto insertion = ranges::upper_bound(begin, it, *it);
+        auto insertion = ranges::upper_bound(first, it, *it);
         ranges::rotate(insertion, it, std::next(it));
     }
 }
@@ -123,7 +123,7 @@ void insertion_sort(Rng && rng)
 std::unique_ptr<int> data(int i)
 {
     std::unique_ptr<int> a(new int[i]);
-    auto rng = ranges::view::counted(a.get(), i);
+    auto rng = ranges::views::counted(a.get(), i);
     ranges::iota(rng, 0);
     return a;
 }
@@ -131,8 +131,8 @@ std::unique_ptr<int> data(int i)
 template<typename Gen>
 void shuffle(int *a, int i, Gen && rand)
 {
-    auto rng = ranges::view::counted(a, i);
-    rng |= ranges::action::shuffle(std::forward<Gen>(rand));
+    auto rng = ranges::views::counted(a, i);
+    rng |= ranges::actions::shuffle(std::forward<Gen>(rand));
 }
 
 constexpr int cloops = 3;
@@ -163,7 +163,7 @@ void benchmark_counted(int i)
     {
         ::shuffle(a.get(), i, gen);
         timer t;
-        insertion_sort(ranges::view::counted(I{a.get()}, i));
+        insertion_sort(ranges::views::counted(I{a.get()}, i));
         ms += t.elapsed();
     }
     std::cout << to_millis(ms/cloops) << std::endl;
