@@ -22,13 +22,13 @@ int main()
 {
     using namespace ranges;
 
-    std::vector<int> v = view::ints(0,10);
+    auto v = views::ints(0,10) | to<std::vector>();
 
-    auto v0 = v | copy | action::transform([](int i){return i*i;});
-    ::models<concepts::Same>(v, v0);
+    auto v0 = v | copy | actions::transform([](int i){return i*i;});
+    CPP_assert(same_as<decltype(v), decltype(v0)>);
     ::check_equal(v0, {0,1,4,9,16,25,36,49,64,81});
 
-    action::transform(v, [](int i){return i*i;});
+    actions::transform(v, [](int i){return i*i;});
     ::check_equal(v, {0,1,4,9,16,25,36,49,64,81});
 
     return ::test_result();
