@@ -15,7 +15,10 @@
 #include <range/v3/algorithm/any_of.hpp>
 #include "../simple_test.hpp"
 
-bool even(int n) { return n % 2 == 0; }
+constexpr bool even(int n)
+{
+    return n % 2 == 0;
+}
 
 struct S {
   S(bool p) : test(p) { }
@@ -25,6 +28,11 @@ struct S {
   bool test;
 };
 
+constexpr bool test_constexpr(std::initializer_list<int> il)
+{
+    return ranges::any_of(il, even);
+}
+
 int main()
 {
   std::vector<int> all_even { 0, 2, 4, 6 };
@@ -59,5 +67,9 @@ int main()
   CHECK(ranges::any_of(ILS{S(false), S(true), S(false)}, &S::p));
   CHECK(!ranges::any_of(ILS{S(false), S(false), S(false)}, &S::p));
 
+  STATIC_CHECK(test_constexpr({0, 2, 4, 6}));
+  STATIC_CHECK(test_constexpr({1, 3, 4, 7}));
+  STATIC_CHECK(!test_constexpr({1, 3, 5, 7}));
+
   return ::test_result();
 }
