@@ -32,7 +32,7 @@ template<class Iter, class Sent = Iter>
 void test()
 {
     int ir[] = {5, 6, 7, 8, 9};
-    constexpr unsigned s = ranges::size(ir);
+    constexpr auto s = ranges::size(ir);
     {
         int ia[] = {1, 2, 3, 4, 5};
         ranges::iota(Iter(ia), Sent(ia + s), 5);
@@ -41,7 +41,7 @@ void test()
 
     {
         int ia[] = {1, 2, 3, 4, 5};
-        auto rng = ranges::make_iterator_range(Iter(ia), Sent(ia + s));
+        auto rng = ranges::make_subrange(Iter(ia), Sent(ia + s));
         ranges::iota(rng, 5);
         CHECK(ranges::equal(ia, ir));
     }
@@ -49,16 +49,16 @@ void test()
 
 int main()
 {
-    test<input_iterator<int*> >();
-    test<forward_iterator<int*> >();
-    test<bidirectional_iterator<int*> >();
-    test<random_access_iterator<int*> >();
+    test<InputIterator<int*> >();
+    test<ForwardIterator<int*> >();
+    test<BidirectionalIterator<int*> >();
+    test<RandomAccessIterator<int*> >();
     test<int*>();
 
-    test<input_iterator<int*>, sentinel<int*> >();
-    test<forward_iterator<int*>, sentinel<int*> >();
-    test<bidirectional_iterator<int*>, sentinel<int*> >();
-    test<random_access_iterator<int*>, sentinel<int*> >();
+    test<InputIterator<int*>, Sentinel<int*> >();
+    test<ForwardIterator<int*>, Sentinel<int*> >();
+    test<BidirectionalIterator<int*>, Sentinel<int*> >();
+    test<RandomAccessIterator<int*>, Sentinel<int*> >();
 
     return ::test_result();
 }
