@@ -45,7 +45,7 @@
 #if defined(RANGES_CXX_HAS_SLOC_BUILTINS) && defined(__has_include)
 #if __has_include(<source_location>)
 #include <source_location>
-#if __cpp_lib_source_location
+#ifdef __cpp_lib_source_location
 #define RANGES_HAS_SLOC 1
 using source_location = std::source_location;
 #endif
@@ -85,9 +85,8 @@ CPP_concept both_ranges = ranges::input_range<T> && ranges::input_range<U>;
 struct check_equal_fn
 {
     CPP_template(typename T, typename U)(
-        /// \pre
         requires(!both_ranges<T, U>))     //
-    void operator()(
+    constexpr void operator()(
         T && actual, U && expected,
         source_location sloc = source_location::current()) const
     {
@@ -95,9 +94,8 @@ struct check_equal_fn
     }
 
     CPP_template(typename Rng1, typename Rng2)(
-        /// \pre
         requires both_ranges<Rng1, Rng2>)
-    void operator()(
+    constexpr void operator()(
         Rng1 && actual, Rng2 && expected,
         source_location sloc = source_location::current()) const
     {
@@ -112,9 +110,8 @@ struct check_equal_fn
     }
 
     CPP_template(typename Rng, typename Val)(
-        /// \pre
         requires ranges::input_range<Rng>)
-    void operator()(
+    constexpr void operator()(
         Rng && actual, std::initializer_list<Val> && expected,
         source_location sloc = source_location::current()) const
     {
@@ -128,7 +125,7 @@ inline namespace function_objects
 }
 
 template<typename Expected, typename Actual>
-void has_type(Actual &&)
+constexpr void has_type(Actual &&)
 {
     static_assert(std::is_same<Expected, Actual>::value, "Not the same");
 }
@@ -136,13 +133,13 @@ void has_type(Actual &&)
 template<ranges::cardinality Expected, 
          typename Rng, 
          ranges::cardinality Actual = ranges::range_cardinality<Rng>::value>
-void has_cardinality(Rng &&)
+constexpr void has_cardinality(Rng &&)
 {
     static_assert(Actual == Expected, "Unexpected cardinality");
 }
 
 template<typename T>
-T & as_lvalue(T && t)
+constexpr T & as_lvalue(T && t)
 {
     return t;
 }
