@@ -106,7 +106,7 @@ int main()
 #if !defined(__GNUC__) || __GNUC__ != 4 || __GNUC_MINOR__ > 8
     static_assert(std::is_same<
         common_reference_t<common_pair<int const &, int const &>, std::pair<int, int>>,
-        std::pair<int, int>
+        common_pair<int, int>
     >::value, "");
 
     static_assert(std::is_same<
